@@ -72,13 +72,6 @@ cov_q_cutoff                = 90
 min_match_length            = 524288  # 100 Kbp  102400
 # mag_metadata                = '%s/file_in/MAG_metadata.txt'                                 % wd
 
-
-'''
-GI_0414_specific	Rd_1	|	50	49	1	0	49/49(100.0)	|	32	32	0	0	0	32/97(32.99)	32/32(100.0)
-GI_0414_specific	Rd_2	|	22	22	0	0	22/22(100.0)	|	16	16	0	0	0	16/97(16.49)	16/16(100.0)
-GI_0414_specific	Both	|	72	71	1	0	71/71(100.0)	|	48	48	0	0	0	48/97(49.48)	48/48(100.0)
-
-'''
 ########## 16S to reference ##########
 
 perform_blastn_16s_vs_refs  = False  # True or False
@@ -92,23 +85,118 @@ total_query_mag_num         = 87
 
 ########## assessment results ##########
 
-MarkerMAG_linkages          = '%s/Oral_0622_60_60_polish_linkages_by_genome.txt'             % wd
+MarkerMAG_linkages          = '%s/Oral_0719_45_45_min1500_diff10_linkages_by_genome.txt'             % wd
 linkages_from_rd1           = False
 
+
+# MarkerMAG_linkages          = '/Users/songweizhi/Desktop/tunning_rd1_Oral/stats_combined_filtered.txt'
+# MarkerMAG_linkages          = '/Users/songweizhi/Desktop/tunning_rd2_Oral/stats_GapFilling_gnm_filtered.txt'
+# linkages_from_rd1           = True
+
 '''
+Oral_0719_45_45_min1200_linkages_by_genome.txt	Rd_1	|	59	58	1	0	58/58(100.0)	|	14	14	0	0	0	14/14(100.0)
+Oral_0719_45_45_min1200_linkages_by_genome.txt	Rd_2	|	11	10	0	1	10/11(90.91)	|	7	6	0	1	0	6/7(85.71)
+Oral_0719_45_45_min1200_linkages_by_genome.txt	Both	|	70	68	1	1	68/69(98.55)	|	21	20	0	1	0	20/21(95.24)
+
+Oral_0719_60_60_min1200_linkages_by_genome.txt	Rd_1	|	43	42	1	0	42/42(100.0)	|	13	13	0	0	0	13/13(100.0)
+Oral_0719_60_60_min1200_linkages_by_genome.txt	Rd_2	|	7	6	0	1	6/7(85.71)	|	4	3	0	1	0	3/4(75.0)
+Oral_0719_60_60_min1200_linkages_by_genome.txt	Both	|	50	48	1	1	48/49(97.96)	|	17	16	0	1	0	16/17(94.12)
+
+Oral_0719_45_45_min1500_linkages_by_genome.txt	Rd_1	|	46	46	0	0	46/46(100.0)	|	13	13	0	0	0	13/13(100.0)
+Oral_0719_45_45_min1500_linkages_by_genome.txt	Rd_2	|	0	0	0	0	0/0(0)	        |	0	0	0	0	0	0/0(0)
+Oral_0719_45_45_min1500_linkages_by_genome.txt	Both	|	46	46	0	0	46/46(100.0)	|	13	13	0	0	0	13/13(100.0)
+
+Oral_0719_45_45_min1500_diff10_linkages_by_genome.txt	Rd_1	|	52	52	0	0	52/52(100.0)	|	13	13	0	0	0	13/13(100.0)
+Oral_0719_45_45_min1500_diff10_linkages_by_genome.txt	Rd_2	|	0	0	0	0	0/0(0)	        |	0	0	0	0	0	0/0(0)
+Oral_0719_45_45_min1500_diff10_linkages_by_genome.txt	Both	|	52	52	0	0	52/52(100.0)	|	13	13	0	0	0	13/13(100.0)
+
+Oral_0719_60_60_min1500_linkages_by_genome.txt	Rd_1	|	36	36	0	0	36/36(100.0)	|	12	12	0	0	0	12/12(100.0)
+Oral_0719_60_60_min1500_linkages_by_genome.txt	Rd_2	|	8	8	0	0	8/8(100.0)	    |	5	5	0	0	0	5/5(100.0)
+Oral_0719_60_60_min1500_linkages_by_genome.txt	Both	|	44	44	0	0	44/44(100.0)	|	17	17	0	0	0	17/17(100.0)
 
 
 
-Oral_0622_60_60_polish_linkages_by_genome.txt	Round	|	Link	Yes	NA	No	Accuracy	|	MAG	Yes	NA	No	Y/N	Accuracy
+
+
+Oral_0718_45_45_min1200_linkages_by_genome.txt	Rd_1	|	60	59	1	0	59/59(100.0)	|	15	15	0	0	0	15/15(100.0)
+Oral_0718_45_45_min1200_linkages_by_genome.txt	Rd_2	|	11	10	0	1	10/11(90.91)	|	7	6	0	1	0	6/7(85.71)
+Oral_0718_45_45_min1200_linkages_by_genome.txt	Both	|	71	69	1	1	69/70(98.57)	|	22	21	0	1	0	21/22(95.45)
+
+Oral_0718_60_60_min1500_linkages_by_genome.txt	Rd_1	|	37	37	0	0	37/37(100.0)	|	13	13	0	0	0	13/13(100.0)
+Oral_0718_60_60_min1500_linkages_by_genome.txt	Rd_2	|	8	5	0	3	5/8(62.5)	|	5	4	0	1	0	4/5(80.0)
+Oral_0718_60_60_min1500_linkages_by_genome.txt	Both	|	45	42	0	3	42/45(93.33)	|	18	17	0	1	0	17/18(94.44)
+
+Oral_0717_45_45_min1200_linkages_by_genome.txt	Rd_1	|	60	59	1	0	59/59(100.0)	|	15	15	0	0	0	15/15(100.0)
+Oral_0717_45_45_min1200_linkages_by_genome.txt	Rd_2	|	12	10	0	2	10/12(83.33)	|	8	6	0	2	0	6/8(75.0)
+Oral_0717_45_45_min1200_linkages_by_genome.txt	Both	|	72	69	1	2	69/71(97.18)	|	23	21	0	2	0	21/23(91.3)
+
+Oral_0715_45_45_min1200_linkages_by_genome.txt	Rd_1	|	60	59	1	0	59/59(100.0)	|	15	15	0	0	0	15/15(100.0)
+Oral_0715_45_45_min1200_linkages_by_genome.txt	Rd_2	|	12	10	0	2	10/12(83.33)	|	8	6	0	2	0	7/8(87.5)
+Oral_0715_45_45_min1200_linkages_by_genome.txt	Both	|	72	69	1	2	69/71(97.18)	|	23	21	0	2	0	22/23(95.7)
+
+Oral_0715_60_60_min1200_linkages_by_genome.txt	Rd_1	|	44	43	1	0	43/43(100.0)	|	14	14	0	0	0	14/14(100.0)
+Oral_0715_60_60_min1200_linkages_by_genome.txt	Rd_2	|	8	7	0	1	7/8(87.5)	    |	5	4	0	1	0	5/5(100.0)
+Oral_0715_60_60_min1200_linkages_by_genome.txt	Both	|	52	50	1	1	50/51(98.04)	|	19	18	0	1	0	19/19(100.0)
+
+Oral_0715_45_45_min1200_linkages_by_genome.txt	Rd_1	|	60	59	1	0	59/59(100.0)	|	15	15	0	0	0	15/15(100.0)
+Oral_0715_45_45_min1200_linkages_by_genome.txt	Rd_2	|	12	10	0	2	10/12(83.33)	|	8	6	0	2	0	6/8(75.0)
+Oral_0715_45_45_min1200_linkages_by_genome.txt	Both	|	72	69	1	2	69/71(97.18)	|	23	21	0	2	0	21/23(91.3)
+
+Oral_0715_60_60_min1200_linkages_by_genome.txt	Rd_1	|	44	43	1	0	43/43(100.0)	|	14	14	0	0	0	14/14(100.0)
+Oral_0715_60_60_min1200_linkages_by_genome.txt	Rd_2	|	8	7	0	1	7/8(87.5)	    |	5	4	0	1	0	4/5(80.0)
+Oral_0715_60_60_min1200_linkages_by_genome.txt	Both	|	52	50	1	1	50/51(98.04)	|	19	18	0	1	0	18/19(94.74)
+
+Oral_0715_60_60_min1500_linkages_by_genome.txt	Rd_1	|	37	37	0	0	37/37(100.0)	|	13	13	0	0	0	13/13(100.0)
+Oral_0715_60_60_min1500_linkages_by_genome.txt	Rd_2	|	8	5	0	3	5/8(62.5)	    |	5	4	0	1	0	4/5(80.0)
+Oral_0715_60_60_min1500_linkages_by_genome.txt	Both	|	45	42	0	3	42/45(93.33)	|	18	17	0	1	0	17/18(94.44)
+
+good!!!
+Oral_0713_60_60_min1500_linkages_by_genome.txt	Rd_1	|	45	40	0	5	40/45(88.89)	|	15	14	0	1	0	14/15(93.33)
+Oral_0713_60_60_min1500_linkages_by_genome.txt	Rd_2	|	10	10	0	0	10/10(100.0)	|	3	3	0	0	0	3/3(100.0)
+Oral_0713_60_60_min1500_linkages_by_genome.txt	Both	|	55	50	0	5	50/55(90.91)	|	18	17	0	1	0	17/18(94.44)
+good!!!
+Oral_0713_60_60_min1200_linkages_by_genome.txt	Rd_1	|	49	43	1	5	43/48(89.58)	|	15	14	0	1	0	14/15(93.33)
+Oral_0713_60_60_min1200_linkages_by_genome.txt	Rd_2	|	4	3	0	1	3/4(75.0)	    |	3	2	0	1	0	2/3(66.67)
+Oral_0713_60_60_min1200_linkages_by_genome.txt	Both	|	53	46	1	6	46/52(88.46)	|	18	16	0	2	0	16/18(88.89)
+
+Oral_0713_45_45_min1200_linkages_by_genome.txt	Rd_1	|	93	81	1	11	81/92(88.04)	|	22	18	0	4	0	18/22(81.82)
+Oral_0713_45_45_min1200_linkages_by_genome.txt	Rd_2	|	15	5	0	10	5/15(33.33)	    |	7	4	0	3	0	4/7(57.14)
+Oral_0713_45_45_min1200_linkages_by_genome.txt	Both	|	108	86	1	21	86/107(80.37)	|	29	22	0	7	0	22/29(75.86)
+
+Oral_0708_60_60_min1200_mask_linkages_by_genome.txt	Rd_1	|	50	43	1	6	43/49(87.76)	|	16	14	0	2	0	14/16(87.5)
+Oral_0708_60_60_min1200_mask_linkages_by_genome.txt	Rd_2	|	16	12	0	4	12/16(75.0)	    |	4	2	0	2	0	2/4(50.0)
+Oral_0708_60_60_min1200_mask_linkages_by_genome.txt	Both	|	66	55	1	10	55/65(84.62)	|	20	16	0	4	0	16/20(80.0)
+Oral_0708_60_60_min1500_mask_linkages_by_genome.txt	Rd_1	|	46	40	0	6	40/46(86.96)	|	16	14	0	2	0	14/16(87.5)
+Oral_0708_60_60_min1500_mask_linkages_by_genome.txt	Rd_2	|	9	1	0	8	1/9(11.11)	    |	2	1	0	1	0	1/2(50.0)
+Oral_0708_60_60_min1500_mask_linkages_by_genome.txt	Both	|	55	41	0	14	41/55(74.55)	|	18	15	0	3	0	15/18(83.33)
+Oral_0705_60_60_min1500_linkages_by_genome.txt	Rd_1	|	45	42	0	3	42/45(93.33)	|	16	15	0	1	0	15/16(93.75)
+Oral_0705_60_60_min1500_linkages_by_genome.txt	Rd_2	|	5	5	0	0	5/5(100.0)	    |	2	2	0	0	0	2/2(100.0)
+Oral_0705_60_60_min1500_linkages_by_genome.txt	Both	|	50	47	0	3	47/50(94.0)	    |	18	17	0	1	0	17/18(94.44)
+Oral_0705_60_60_min1400_linkages_by_genome.txt	Rd_1	|	38	37	0	1	37/38(97.37)	|	15	14	0	1	0	14/15(93.33)
+Oral_0705_60_60_min1400_linkages_by_genome.txt	Rd_2	|	17	1	0	16	1/17(5.88)	    |	3	0	0	3	0	0/3(0.0)
+Oral_0705_60_60_min1400_linkages_by_genome.txt	Both	|	55	38	0	17	38/55(69.09)	|	18	14	0	4	0	14/18(77.78)
+Oral_0622_60_60_polish_min1200_99_127_linkages_by_genome.txt	Rd_1	|	44	39	1	4	39/43(90.7)	    |	16	15	0	1	0	15/16(93.75)
+Oral_0622_60_60_polish_min1200_99_127_linkages_by_genome.txt	Rd_2	|	20	6	0	14	6/20(30.0)	    |	3	1	0	2	0	1/3(33.33)
+Oral_0622_60_60_polish_min1200_99_127_linkages_by_genome.txt	Both	|	64	45	1	18	45/63(71.43)	|	19	16	0	3	0	16/19(84.21)
+Oral_0622_60_60_polish_new_linkages_by_genome.txt	Rd_1	|	46	44	1	1	44/45(97.78)	|	16	15	0	1	0	15/16(93.75)
+Oral_0622_60_60_polish_new_linkages_by_genome.txt	Rd_2	|	23	9	0	14	9/23(39.13)	    |	4	2	0	2	0	2/4(50.0)
+Oral_0622_60_60_polish_new_linkages_by_genome.txt	Both	|	69	53	1	15	53/68(77.94)	|	20	17	0	3	0	17/20(85.0)
+Oral_0622_60_60_polish_min1200_75_127_linkages_by_genome.txt	Rd_1	|	45	43	1	1	43/44(97.73)	|	16	15	0	1	0	15/16(93.75)
+Oral_0622_60_60_polish_min1200_75_127_linkages_by_genome.txt	Rd_2	|	23	7	0	16	7/23(30.43)	    |	4	1	0	3	0	1/4(25.0)
+Oral_0622_60_60_polish_min1200_75_127_linkages_by_genome.txt	Both	|	68	50	1	17	50/67(74.63)	|	20	16	0	4	0	16/20(80.0)
+Oral_0622_60_60_polish_min1200_linkages_by_genome.txt	Rd_1	|	50	44	1	5	44/49(89.8)	    |	16	15	0	1	0	15/16(93.75)
+Oral_0622_60_60_polish_min1200_linkages_by_genome.txt	Rd_2	|	14	11	0	3	11/14(78.57)	|	3	1	0	2	0	1/3(33.33)
+Oral_0622_60_60_polish_min1200_linkages_by_genome.txt	Both	|	64	55	1	8	55/63(87.3)	    |	19	16	0	3	0	16/19(84.21)
+Oral_0622_60_60_polish_min1000_linkages_by_genome.txt	Rd_1	|	48	42	1	5	42/47(89.36)	|	16	15	0	1	0	15/16(93.75)
+Oral_0622_60_60_polish_min1000_linkages_by_genome.txt	Rd_2	|	25	8	0	17	8/25(32.0)	    |	5	2	0	3	0	2/5(40.0)
+Oral_0622_60_60_polish_min1000_linkages_by_genome.txt	Both	|	73	50	1	22	50/72(69.44)	|	21	17	0	4	0	17/21(80.95)
+Oral_0622_60_60_polish_min900_linkages_by_genome.txt	Rd_1	|	48	45	1	2	45/47(95.74)	|	16	14	0	1	1	14/16(87.5)
+Oral_0622_60_60_polish_min900_linkages_by_genome.txt	Rd_2	|	33	14	0	19	14/33(42.42)	|	7	3	0	4	0	3/7(42.86)
+Oral_0622_60_60_polish_min900_linkages_by_genome.txt	Both	|	81	59	1	21	59/80(73.75)	|	23	17	0	5	1	17/23(73.91)
 Oral_0622_60_60_polish_linkages_by_genome.txt	Rd_1	|	63	52	8	3	52/55(94.55)	|	20	16	1	2	1	16/19(84.21)
 Oral_0622_60_60_polish_linkages_by_genome.txt	Rd_2	|	14	10	0	4	10/14(71.43)	|	6	3	0	3	0	3/6(50.0)
 Oral_0622_60_60_polish_linkages_by_genome.txt	Both	|	77	62	8	7	62/69(89.86)	|	26	19	1	5	1	19/25(76.0)
 
-Oral_0622_60_60_linkages_by_genome.txt	Round	|	Link	Yes	NA	No	Accuracy	|	MAG	Yes	NA	No	Y/N	Accuracy
-Oral_0622_60_60_linkages_by_genome.txt	Rd_1	|	73	63	5	5	63/68(92.65)	|	26	20	1	4	1	20/25(80.0)
-Oral_0622_60_60_linkages_by_genome.txt	Rd_2	|	12	5	5	2	5/7(71.43)	|	6	3	1	2	0	3/5(60.0)
-Oral_0622_60_60_linkages_by_genome.txt	Both	|	85	68	10	7	68/75(90.67)	|	32	23	2	6	1	23/30(76.67)
-
 '''
 
 ########## script ##########
@@ -147,7 +235,6 @@ for each_ref in open(drep_cdb_file):
         else:
             cluster_to_ref_dict[ref_cluster].append(ref_file_name_no_ext)
 
-print('cluster_to_ref_dict: %s' % len(cluster_to_ref_dict) )
 
 ################################################### bin to reference ###################################################
 
@@ -503,36 +590,52 @@ BioSAK iTOL -ColorRange -lg leaf_group_raw.txt -lt Identity -out leaf_group.txt
 ########################################################################################################################
 
 '''
-cluster_id = 'C107_0'
-print('cluster to ref  : %s\t%s\t%s' % (cluster_id, len(cluster_to_ref_dict.get(cluster_id, 'NA')), cluster_to_ref_dict.get(cluster_id, 'NA')))
-print('cluster to MAG  : %s\t%s\t%s' % (cluster_id, len(cluster_to_bin_dict.get(cluster_id, 'NA')), cluster_to_bin_dict.get(cluster_id, 'NA')))
-print('cluster to Matam: %s\t%s\t%s' % (cluster_id, len(cluster_to_matam_16s_dict.get(cluster_id, 'NA')), cluster_to_matam_16s_dict.get(cluster_id, 'NA')))
-#print('cluster to MAG: %s\t%s' % ('C126_5', cluster_to_bin_dict.get('C126_5', 'NA')))
+# cluster_id = 'C161_2'
+# print('cluster to ref  : %s\t%s\t%s' % (cluster_id, len(cluster_to_ref_dict.get(cluster_id, 'NA')), cluster_to_ref_dict.get(cluster_id, 'NA')))
+# print('cluster to MAG  : %s\t%s\t%s' % (cluster_id, len(cluster_to_bin_dict.get(cluster_id, 'NA')), cluster_to_bin_dict.get(cluster_id, 'NA')))
+# print('cluster to Matam: %s\t%s\t%s' % (cluster_id, len(cluster_to_matam_16s_dict.get(cluster_id, 'NA')), cluster_to_matam_16s_dict.get(cluster_id, 'NA')))
+# #print('cluster to MAG: %s\t%s' % ('C126_5', cluster_to_bin_dict.get('C126_5', 'NA')))
 
-print(bin_to_cluster_dict['Oral_70'])
+#
+# print('cluster to MAG  : %s\t%s\t%s' % ('C126_1', len(cluster_to_bin_dict.get('C126_1', 'NA')), cluster_to_bin_dict.get('C126_1', 'NA')))
+# print('cluster to MAG  : %s\t%s\t%s' % ('C126_2', len(cluster_to_bin_dict.get('C126_2', 'NA')), cluster_to_bin_dict.get('C126_2', 'NA')))
+# print('cluster to MAG  : %s\t%s\t%s' % ('C126_3', len(cluster_to_bin_dict.get('C126_3', 'NA')), cluster_to_bin_dict.get('C126_3', 'NA')))
+# print('cluster to MAG  : %s\t%s\t%s' % ('C126_4', len(cluster_to_bin_dict.get('C126_4', 'NA')), cluster_to_bin_dict.get('C126_4', 'NA')))
+#
 
 
-print(matam_16s_to_cluster_dict['CAMI_Oral_subsample_25_317'])
+# print('%s\t%s' % ('CAMI_Oral_subsample_50_735', matam_16s_to_cluster_dict['CAMI_Oral_subsample_50_735']))
+# print('%s\t%s' % ('CAMI_Oral_subsample_50_818', matam_16s_to_cluster_dict['CAMI_Oral_subsample_50_818']))
+# print('%s\t%s' % ('CAMI_Oral_subsample_50_734', matam_16s_to_cluster_dict['CAMI_Oral_subsample_50_734']))
+# print('%s\t%s' % ('CAMI_Oral_subsample_10_308', matam_16s_to_cluster_dict['CAMI_Oral_subsample_10_308']))
+# print('%s\t%s' % ('CAMI_Oral_subsample_50_279', matam_16s_to_cluster_dict['CAMI_Oral_subsample_50_279']))
 
-print('cluster to MAG  : %s\t%s\t%s' % ('C126_1', len(cluster_to_bin_dict.get('C126_1', 'NA')), cluster_to_bin_dict.get('C126_1', 'NA')))
-print('cluster to MAG  : %s\t%s\t%s' % ('C126_2', len(cluster_to_bin_dict.get('C126_2', 'NA')), cluster_to_bin_dict.get('C126_2', 'NA')))
-print('cluster to MAG  : %s\t%s\t%s' % ('C126_3', len(cluster_to_bin_dict.get('C126_3', 'NA')), cluster_to_bin_dict.get('C126_3', 'NA')))
-print('cluster to MAG  : %s\t%s\t%s' % ('C126_4', len(cluster_to_bin_dict.get('C126_4', 'NA')), cluster_to_bin_dict.get('C126_4', 'NA')))
+# print('%s\t%s' % ('CAMI_Oral_subsample_50_894', matam_16s_to_cluster_dict['CAMI_Oral_subsample_50_894']))
+# print('%s\t%s' % ('CAMI_Oral_subsample_50_884', matam_16s_to_cluster_dict['CAMI_Oral_subsample_50_884']))
+# print('%s\t%s' % ('CAMI_Oral_subsample_25_465', matam_16s_to_cluster_dict['CAMI_Oral_subsample_25_465']))
+# print(bin_to_cluster_dict['Oral_28'])
+# print(bin_to_cluster_dict['Oral_42'])
+# print(bin_to_cluster_dict['Oral_43'])
+# print(bin_to_cluster_dict['Oral_44'])
+# print(bin_to_cluster_dict['Oral_46'])
+# print(bin_to_cluster_dict['Oral_47'])
+# print(bin_to_cluster_dict['Oral_53'])
+# print(bin_to_cluster_dict['Oral_57'])
+# print(bin_to_cluster_dict['Oral_65'])
+# print(bin_to_cluster_dict['Oral_70'])
+# print(bin_to_cluster_dict['Oral_72'])
+# print(bin_to_cluster_dict['Oral_75'])
 
 '''
-CAMI_Oral_subsample_50_677	Oral_72	115	Rd1	Correct
-CAMI_Oral_subsample_25_488	Oral_72	115	Rd1	Correct
-CAMI_Oral_subsample_50_70	Oral_70	11	Rd1	Wrong
-CAMI_Oral_subsample_25_51	Oral_70	11	Rd1	Wrong
-CAMI_Oral_subsample_10_42	Oral_70	11	Rd1	Wrong
-CAMI_Oral_subsample_25_317	Oral_70	11	Rd1	Wrong
+CAMI_Oral_subsample_50_894	{'C113_2'}
 
 
 
+Oral_51: C159_1
+CAMI_Oral_subsample_50_735
+CAMI_Oral_subsample_50_818
+CAMI_Oral_subsample_50_734
+CAMI_Oral_subsample_10_308
+CAMI_Oral_subsample_50_279
 
-
-
-
-
-
-'''
\ No newline at end of file
+'''
